@@ -2,7 +2,7 @@
 
 from docx.api import Document  # noqa
 
-__version__ = '0.8.7'
+__version__ = '0.8.8'
 
 
 # register custom Part classes with opc package reader
@@ -12,6 +12,7 @@ from docx.opc.part import PartFactory
 from docx.opc.parts.coreprops import CorePropertiesPart
 
 from docx.parts.document import DocumentPart
+from docx.parts.hdrftr import FooterPart, HeaderPart
 from docx.parts.image import ImagePart
 from docx.parts.numbering import NumberingPart
 from docx.parts.settings import SettingsPart
@@ -27,11 +28,21 @@ def part_class_selector(content_type, reltype):
 PartFactory.part_class_selector = part_class_selector
 PartFactory.part_type_for[CT.OPC_CORE_PROPERTIES] = CorePropertiesPart
 PartFactory.part_type_for[CT.WML_DOCUMENT_MAIN] = DocumentPart
+PartFactory.part_type_for[CT.WML_FOOTER] = FooterPart
+PartFactory.part_type_for[CT.WML_HEADER] = HeaderPart
 PartFactory.part_type_for[CT.WML_NUMBERING] = NumberingPart
 PartFactory.part_type_for[CT.WML_SETTINGS] = SettingsPart
 PartFactory.part_type_for[CT.WML_STYLES] = StylesPart
 
 del (
-    CT, CorePropertiesPart, DocumentPart, NumberingPart, PartFactory,
-    StylesPart, part_class_selector
+    CT,
+    CorePropertiesPart,
+    DocumentPart,
+    FooterPart,
+    HeaderPart,
+    NumberingPart,
+    PartFactory,
+    SettingsPart,
+    StylesPart,
+    part_class_selector,
 )
